/*
 * Author: Trevor Sherrard
 * Project: Styx Networked LED controller
 * Since: 02/24/2021
 * Description: This arduino sketch will demonstrate the how to interface
 * with the networked LED controller via an i2c interace from an arduino master
 * device. 
 */

#include <Wire.h>

#define I2C_ADDR         4
#define DELAY_VAL        5000
#define FLASH_DELAY      20000
#define RAMP_DELAY       35000

// define color strings. Format is RRGGBBWW
String redString = "FF000000";
String whiteString = "FFFF4000";
String blueString = "0000FF00";

// defind command strings
String holdCommand = "h";
String flashCommand = "f";
String rampCommand = "r";
String strobeCommand = "s";

// define delay and numFlash constants
String numFlash = "05"; // number of flashes
String delayInc = "50"; // number of 100ms increments to complete fade in. 

// defind fade and flash color strings
String rampRed = redString + ":" + delayInc;
String rampWhite = whiteString + ":" + delayInc;
String rampBlue = blueString + ":" + delayInc;
String flashRed = redString + ":" + numFlash;
String flashWhite = whiteString + ":" + numFlash;
String flashBlue = blueString + ":" + numFlash;

void writeCommand(String cmdString, String colorString) {
  // create string to send
  String stringToSend = cmdString + colorString;
  
  // start transmission
  Wire.beginTransmission(I2C_ADDR);

  // send data
  Wire.write(stringToSend.c_str());

  // end transmission
  Wire.endTransmission();
}

void setup() {
  // set up serial interface
  Serial.begin(9600);

  // join i2c bus as master
  Wire.begin();
}

void loop() {
  // first demonstrate the hold command
  writeCommand(holdCommand, redString);
  delay(DELAY_VAL);
  writeCommand(holdCommand, whiteString);
  delay(DELAY_VAL);
  writeCommand(holdCommand, blueString);
  delay(DELAY_VAL);

  // then, demonstrate the flash command
  writeCommand(flashCommand, flashRed);
  delay(FLASH_DELAY);
  writeCommand(flashCommand, flashWhite);
  delay(FLASH_DELAY);
  writeCommand(flashCommand, flashBlue);
  delay(FLASH_DELAY);

  // then, demonstrate the fade/ramp command
  writeCommand(rampCommand, rampRed);
  delay(RAMP_DELAY);
  writeCommand(rampCommand, rampWhite);
  delay(RAMP_DELAY);
  writeCommand(rampCommand, rampBlue);
  delay(RAMP_DELAY);

  // then, demonstrate the strobe command
  writeCommand(strobeCommand, redString);
  delay(DELAY_VAL);
  writeCommand(strobeCommand, whiteString);
  delay(DELAY_VAL);
  writeCommand(strobeCommand, blueString);
  delay(DELAY_VAL);
}
